# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class Gate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fidelity': 'float',
        'fidelity_change_per_day': 'float',
        'qubit_from': 'Qubit',
        'qubit_to': 'Qubit',
        'gate_type': 'str'
    }

    attribute_map = {
        'fidelity': 'fidelity',
        'fidelity_change_per_day': 'fidelityChangePerDay',
        'qubit_from': 'qubitFrom',
        'qubit_to': 'qubitTo',
        'gate_type': 'gateType'
    }

    def __init__(self, fidelity=None, fidelity_change_per_day=None, qubit_from=None, qubit_to=None, gate_type=None, local_vars_configuration=None):  # noqa: E501
        """Gate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._fidelity = None
        self._fidelity_change_per_day = None
        self._qubit_from = None
        self._qubit_to = None
        self._gate_type = None
        self.discriminator = None

        if fidelity is not None:
            self.fidelity = fidelity
        if fidelity_change_per_day is not None:
            self.fidelity_change_per_day = fidelity_change_per_day
        if qubit_from is not None:
            self.qubit_from = qubit_from
        if qubit_to is not None:
            self.qubit_to = qubit_to
        if gate_type is not None:
            self.gate_type = gate_type

    @property
    def fidelity(self):
        """Gets the fidelity of this Gate.  # noqa: E501


        :return: The fidelity of this Gate.  # noqa: E501
        :rtype: float
        """
        return self._fidelity

    @fidelity.setter
    def fidelity(self, fidelity):
        """Sets the fidelity of this Gate.


        :param fidelity: The fidelity of this Gate.  # noqa: E501
        :type: float
        """

        self._fidelity = fidelity

    @property
    def fidelity_change_per_day(self):
        """Gets the fidelity_change_per_day of this Gate.  # noqa: E501


        :return: The fidelity_change_per_day of this Gate.  # noqa: E501
        :rtype: float
        """
        return self._fidelity_change_per_day

    @fidelity_change_per_day.setter
    def fidelity_change_per_day(self, fidelity_change_per_day):
        """Sets the fidelity_change_per_day of this Gate.


        :param fidelity_change_per_day: The fidelity_change_per_day of this Gate.  # noqa: E501
        :type: float
        """

        self._fidelity_change_per_day = fidelity_change_per_day

    @property
    def qubit_from(self):
        """Gets the qubit_from of this Gate.  # noqa: E501


        :return: The qubit_from of this Gate.  # noqa: E501
        :rtype: Qubit
        """
        return self._qubit_from

    @qubit_from.setter
    def qubit_from(self, qubit_from):
        """Sets the qubit_from of this Gate.


        :param qubit_from: The qubit_from of this Gate.  # noqa: E501
        :type: Qubit
        """

        self._qubit_from = qubit_from

    @property
    def qubit_to(self):
        """Gets the qubit_to of this Gate.  # noqa: E501


        :return: The qubit_to of this Gate.  # noqa: E501
        :rtype: Qubit
        """
        return self._qubit_to

    @qubit_to.setter
    def qubit_to(self, qubit_to):
        """Sets the qubit_to of this Gate.


        :param qubit_to: The qubit_to of this Gate.  # noqa: E501
        :type: Qubit
        """

        self._qubit_to = qubit_to

    @property
    def gate_type(self):
        """Gets the gate_type of this Gate.  # noqa: E501


        :return: The gate_type of this Gate.  # noqa: E501
        :rtype: str
        """
        return self._gate_type

    @gate_type.setter
    def gate_type(self, gate_type):
        """Sets the gate_type of this Gate.


        :param gate_type: The gate_type of this Gate.  # noqa: E501
        :type: str
        """

        self._gate_type = gate_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Gate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Gate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Honeywell

    This is an api to connect to the Honeywell backend  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import honeywell
from honeywell.models.job_post_parameters import JobPostParameters  # noqa: E501
from honeywell.rest import ApiException

class TestJobPostParameters(unittest.TestCase):
    """JobPostParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobPostParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = honeywell.models.job_post_parameters.JobPostParameters()  # noqa: E501
        if include_optional :
            return JobPostParameters(
                count = 56, 
                language = 'OPENQASM 2.0', 
                machine = '0', 
                max_cost = 56, 
                name = '0', 
                notify = True, 
                options = [
                    '0'
                    ], 
                priority = 'high', 
                program = '0'
            )
        else :
            return JobPostParameters(
                language = 'OPENQASM 2.0',
                machine = '0',
                program = '0',
        )

    def testJobPostParameters(self):
        """Test JobPostParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.qubit import Qubit  # noqa: E501
from openapi_client.rest import ApiException

class TestQubit(unittest.TestCase):
    """Qubit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Qubit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.qubit.Qubit()  # noqa: E501
        if include_optional :
            return Qubit(
                fidelity_rotation = 1.337, 
                last_reported_fidelity_rotation_datetime = '0', 
                name = 56, 
                pos_x = 1.337, 
                pos_y = 1.337, 
                real_qubit = 56
            )
        else :
            return Qubit(
        )

    def testQubit(self):
        """Test Qubit"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class SubmissionSummaryJobs(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cancelled': 'list[str]',
        'completed': 'list[str]',
        'error': 'list[str]',
        'initiated': 'list[str]',
        'in_progress': 'list[str]'
    }

    attribute_map = {
        'cancelled': 'cancelled',
        'completed': 'completed',
        'error': 'error',
        'initiated': 'initiated',
        'in_progress': 'inProgress'
    }

    def __init__(self, cancelled=None, completed=None, error=None, initiated=None, in_progress=None, local_vars_configuration=None):  # noqa: E501
        """SubmissionSummaryJobs - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cancelled = None
        self._completed = None
        self._error = None
        self._initiated = None
        self._in_progress = None
        self.discriminator = None

        if cancelled is not None:
            self.cancelled = cancelled
        if completed is not None:
            self.completed = completed
        if error is not None:
            self.error = error
        if initiated is not None:
            self.initiated = initiated
        if in_progress is not None:
            self.in_progress = in_progress

    @property
    def cancelled(self):
        """Gets the cancelled of this SubmissionSummaryJobs.  # noqa: E501


        :return: The cancelled of this SubmissionSummaryJobs.  # noqa: E501
        :rtype: list[str]
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this SubmissionSummaryJobs.


        :param cancelled: The cancelled of this SubmissionSummaryJobs.  # noqa: E501
        :type: list[str]
        """

        self._cancelled = cancelled

    @property
    def completed(self):
        """Gets the completed of this SubmissionSummaryJobs.  # noqa: E501


        :return: The completed of this SubmissionSummaryJobs.  # noqa: E501
        :rtype: list[str]
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this SubmissionSummaryJobs.


        :param completed: The completed of this SubmissionSummaryJobs.  # noqa: E501
        :type: list[str]
        """

        self._completed = completed

    @property
    def error(self):
        """Gets the error of this SubmissionSummaryJobs.  # noqa: E501


        :return: The error of this SubmissionSummaryJobs.  # noqa: E501
        :rtype: list[str]
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this SubmissionSummaryJobs.


        :param error: The error of this SubmissionSummaryJobs.  # noqa: E501
        :type: list[str]
        """

        self._error = error

    @property
    def initiated(self):
        """Gets the initiated of this SubmissionSummaryJobs.  # noqa: E501


        :return: The initiated of this SubmissionSummaryJobs.  # noqa: E501
        :rtype: list[str]
        """
        return self._initiated

    @initiated.setter
    def initiated(self, initiated):
        """Sets the initiated of this SubmissionSummaryJobs.


        :param initiated: The initiated of this SubmissionSummaryJobs.  # noqa: E501
        :type: list[str]
        """

        self._initiated = initiated

    @property
    def in_progress(self):
        """Gets the in_progress of this SubmissionSummaryJobs.  # noqa: E501


        :return: The in_progress of this SubmissionSummaryJobs.  # noqa: E501
        :rtype: list[str]
        """
        return self._in_progress

    @in_progress.setter
    def in_progress(self, in_progress):
        """Sets the in_progress of this SubmissionSummaryJobs.


        :param in_progress: The in_progress of this SubmissionSummaryJobs.  # noqa: E501
        :type: list[str]
        """

        self._in_progress = in_progress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubmissionSummaryJobs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubmissionSummaryJobs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Honeywell

    This is an api to connect to the Honeywell backend  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import honeywell
from honeywell.api.job_api import JobApi  # noqa: E501
from honeywell.rest import ApiException


class TestJobApi(unittest.TestCase):
    """JobApi unit test stubs"""

    def setUp(self):
        self.api = honeywell.api.job_api.JobApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_post(self):
        """Test case for job_post

        Quantum job may be submitted using the following API  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Honeywell

    This is an api to connect to the Honeywell backend  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import honeywell
from honeywell.models.inline_response_default import InlineResponseDefault  # noqa: E501
from honeywell.rest import ApiException

class TestInlineResponseDefault(unittest.TestCase):
    """InlineResponseDefault unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponseDefault
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = honeywell.models.inline_response_default.InlineResponseDefault()  # noqa: E501
        if include_optional :
            return InlineResponseDefault(
                error_response = honeywell.models.error_response.ErrorResponse(
                    error = honeywell.models.error_response_error.ErrorResponse_error(
                        code = '0', 
                        text = '0', ), ), 
                job_response = honeywell.models.job_response.JobResponse(
                    job = '0', 
                    status = '0', )
            )
        else :
            return InlineResponseDefault(
        )

    def testInlineResponseDefault(self):
        """Test InlineResponseDefault"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
